.. _class-Topology:

Topology class
==============

.. doxygenclass:: chemfiles::Topology
    :members:

Connectivity elements
=====================

.. doxygenclass:: chemfiles::Bond
    :members:

.. doxygenclass:: chemfiles::Angle
    :members:

.. doxygenclass:: chemfiles::Dihedral
    :members:

.. doxygenclass:: chemfiles::Improper
    :members:
